@@ -6,13 +6,9 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-use utf8;
+use 5.006;
 use strict;
-use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
-
-=encoding utf8
-
-=cut
+use warnings;
 
 package Test::MyCmd;
 use Mouse;
